/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    johan - initial API and implementation and/or initial documentation
 */
package eu.agrosense.client.geotiff;

import java.awt.Image;
import java.util.List;
import java.util.logging.Logger;
import nl.cloudfarming.client.geoviewer.BaseLayer;
import nl.cloudfarming.client.geoviewer.RangedLegendPalette;
import org.geotools.coverage.grid.GridCoverage2D;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author johan
 */
public class GeoTiffChildFactory extends ChildFactory<GridCoverage2D> {
    private static final Logger LOGGER = Logger.getLogger("eu.agrosense.client.geotiff.GeoTiffChildFactory");
    
    private final GeoTiffDataObject dataObject;

    public GeoTiffChildFactory(GeoTiffDataObject dataObject) {
        this.dataObject = dataObject;
    }

    @Override
    protected boolean createKeys(List<GridCoverage2D> toPopulate) {
        //TODO: single file might produce multiple coverages (tiff pages)
        toPopulate.add(dataObject.getCoverage());
        return true;
    }
    
    @Override
    protected Node[] createNodesForKey(GridCoverage2D key) {
        return new Node[] {
            GridNode.create(dataObject) //, new ImageNode((Object[])null)//TODO, hide empty node for now
        };
    }
    
    private static class ChildNode extends AbstractNode {
        private String name;
        private String iconBase;

        public ChildNode(String name, String iconBase, Object... objectsToLookup) {
            super(Children.LEAF, makeLookup(objectsToLookup));
            this.name = name;
            this.iconBase = iconBase;
        }

        @Override
        public String getName() {
            return name;
        }

        @Override
        public Image getIcon(int type) {
            return ImageUtilities.loadImage(iconBase, true);
        }        
    }
    
    private static Lookup makeLookup(Object... objectsToLookup) {
        return objectsToLookup == null || objectsToLookup.length == 0 ? Lookup.EMPTY : Lookups.fixed(objectsToLookup);
    }
    
    @NbBundle.Messages({"GeoTiffChildFactory.ImageNode name=Image"})
    public static class ImageNode extends ChildNode {
        private static final String ICON_BASE = "eu/agrosense/client/geotiff/image.png";
        public ImageNode(Object... objectsToLookup) {
            super(Bundle.GeoTiffChildFactory_ImageNode_name(), ICON_BASE, objectsToLookup);
        }
        
        // let's see if we can use the coverage for this one as well:
        // e.g. use a grayscale palette, or do not use a ColorMap at all and render using the photographic viewtype.
    }
    
    @NbBundle.Messages({"GeoTiffChildFactory.GridNode name=Grid"})
    public static class GridNode extends ChildNode {
        private static final String ICON_BASE = "eu/agrosense/client/geotiff/grid.png";

        private GridNode(Object... objectsToLookup) {
            super(Bundle.GeoTiffChildFactory_GridNode_name(), ICON_BASE, objectsToLookup);
        }
        
        public static GridNode create(GeoTiffDataObject dataObject) {
            RangedLegendPalette<Double> palette = GeoTiffDataObject.getGridPalette(dataObject);
            return new GridNode(
                    palette,
                    new BaseLayer(palette, Bundle.GeoTiffChildFactory_GridNode_name()),
                    new AbstractGeoTiffGeographical.CroppedGridImpl(dataObject.getCoverage()));            
        }
    }
    
}
